==> ae_files-0.0.4.tar.gz: ae_files-0.0.4/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# files portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_files/master?logo=python)](
    https://gitlab.com/ae-group/ae_files)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_files)](
    https://pypi.org/project/ae-files/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_files/coverage.svg)](
    https://ae-group.gitlab.io/ae_files/coverage/ae_files_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_files/mypy.svg)](
    https://ae-group.gitlab.io/ae_files/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_files/pylint.svg)](
    https://ae-group.gitlab.io/ae_files/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_files)](
    https://libraries.io/pypi/ae-files)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_files)](
    https://pypi.org/project/ae-files/#files)


## installation


Execute the following command for to use the ae.files module in your
application. It will install ae.files into your python (virtual) environment:
 
```shell script
pip install ae-files
```

If you instead want to contribute to this portion then first fork
[the ae_files repository at GitLab](https://gitlab.com/ae-group/ae_files "ae.files code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_files):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.files.html#module-ae.files
"ae_files documentation").

<!-- Common files version 0.0.45 deployed  version 0.0.1 (with 0.0.45)
     to https://gitlab.com/ae-group as ae_files module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project as ae-files package.
-->

==> ae_files-0.1.11.tar.gz: ae_files-0.1.11/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# files portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_files/master?logo=python)](
    https://gitlab.com/ae-group/ae_files)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_files)](
    https://pypi.org/project/ae-files/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_files/coverage.svg)](
    https://ae-group.gitlab.io/ae_files/coverage/ae_files_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_files/mypy.svg)](
    https://ae-group.gitlab.io/ae_files/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_files/pylint.svg)](
    https://ae-group.gitlab.io/ae_files/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_files)](
    https://pypi.org/project/ae-files/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_files)](
    https://libraries.io/pypi/ae-files)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_files)](
    https://pypi.org/project/ae-files/#files)


## installation


Execute the following command for to use the ae.files module in your
application. It will install ae.files into your python (virtual) environment:
 
```shell script
pip install ae-files
```

If you instead want to contribute to this portion then first fork
[the ae_files repository at GitLab](https://gitlab.com/ae-group/ae_files "ae.files code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_files):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.files.html#module-ae.files
"ae_files documentation").

<!-- Common files version 0.0.60 deployed version 0.1.4 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_files module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-files as namespace portion ae-files.
-->
